<br />
<div align="center">
  <h3 align="center">Kenexar-Core</h3>

  <p align="center">
    Welcome to the Kenexar Team's base package for Python projects. This project is a collection of our most commonly used code snippets, designed to make your development process more efficient and streamlined.
    <br />
    <a href="https://kenexar.github.io/kenexar-core/"><strong>Explore the docs »</strong></a>
    <br />
    <br />
    <a href="https://github.com/Kenexar/kenexar-core/issues">Report Bug</a>
    ·
    <a href="https://github.com/Kenexar/kenexar-core/issues">Request Feature</a>
  </p>
  <a align="center" href="https://www.codefactor.io/repository/github/kenexar/kenexar-core"><img src="https://www.codefactor.io/repository/github/kenexar/kenexar-core/badge" alt="CodeFactor" /></a>
    <a align="center" href="https://www.python.org/"><img src="https://img.shields.io/badge/Made%20with-Python-1f425f.svg" alt="Python"/></a>
    <a href="https://github.com/Kenexar/kenexar-core/blob/main/LICENSE"><img alt="GitHub license" src="https://img.shields.io/github/license/Kenexar/kenexar-core"></a>
    <img alt="lines of code" src="https://img.shields.io/tokei/lines/github/Kenexar/kenexar-core?&style=plastic&label=Lines%20of%20Code">
</div>


## Installation

To install this package, follow the instructions below:

#### On Windows:
- `pip install kenexar-core`

#### On Linux:
- `python3 -m pip install kenexar-core`

Once the package is installed, you can start using it in your Python project.

## Contributing

If you would like to contribute to this project, please feel free to open issues or pull requests on our GitHub repository.

To set up your development environment, follow these steps:

1. Clone the project using the following command: `git clone https://github.com/kenexar/kenexar-core`
2. If you are using Linux or OSX, or have a Windows Subsystem for Linux (WSL) installed on Windows, you can run the `setup.sh` script to set up your environment: `./setup.sh`
    - If the `setup.sh` script does not work for you, you can set up your environment manually by following these steps:
      1. Create a virtual environment with the following command: `python3 -m venv venv/`
      2. Activate the virtual environment: `venv/Scripts/activate`
      3. Install the required dependencies: `pip install -r req`
3. Once your environment is set up, you can start developing and contributing to the project!

## License

This project is licensed under the MIT license. For more information, see the [LICENSE](LICENSE) file in this repository.

---

Project by [exersalza "Julian J."](https://github.com/exersalza)
